@@ -1,6 +1,6 @@
 use std::collections::{BTreeMap, BTreeSet, HashSet};
 
-use ic_cdk::export::candid::{CandidType, Deserialize, Principal};
+use ic_cdk::export::candid::{decode_one, CandidType, Deserialize, Principal};
 use ic_cdk::{caller, print};
 
 pub mod api;
@@ -29,6 +29,20 @@ pub struct Event {
     pub values: Vec<EventField>,
 }
 
+impl Event {
+    pub fn get_name(&self) -> String {
+        let encoded_name = self
+            .topics
+            .iter()
+            .find(|&field| field.name == EVENT_NAME_FIELD)
+            .cloned()
+            .unwrap()
+            .value;
+
+        decode_one::<String>(encoded_name.as_slice()).unwrap()
+    }
+}
+
 pub trait IEvent {
     fn to_event(&self) -> Event;
     fn from_event(event: Event) -> Self;
